@@ -180,7 +180,7 @@ class ImageGenerator(
             #                                   y_pad_size:-y_pad_size]
 
             if target_img_height != target_img_width:
-                min_size = min(target_img_width, target_img_height)
+                min_size = min(augmented_img.shape[2::])
                 augmented_img = torchvision.transforms.RandomCrop(
                     (min_size, min_size))(augmented_img)
 
